==> jboss-eap-7.4.3-src.zip: jboss-eap-7.4-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/ejb/interceptor/method/TopSecretInterceptor.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.integration.ejb.interceptor.method;

import javax.annotation.PostConstruct;
import javax.interceptor.AroundInvoke;
import javax.interceptor.InvocationContext;

/**
 * @author Stuart Douglas
 */
public class TopSecretInterceptor {

    public static boolean called = false;
    public static boolean postConstructCalled = false;

    // as this is a method level interceptor this should not be called
    // see the interceptors spec
    @PostConstruct
    public void postConstruct(final InvocationContext invocationContext) throws Exception {
        postConstructCalled = true;
        invocationContext.proceed();
    }

    @AroundInvoke
    public Object aroundInvoke(final InvocationContext invocationContext) throws Exception {
        called = true;
        return invocationContext.proceed();
    }
}

==> jboss-eap-8.0.7-src.zip: jboss-eap-8.0-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/ejb/interceptor/method/TopSecretInterceptor.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.integration.ejb.interceptor.method;

import jakarta.annotation.PostConstruct;
import jakarta.interceptor.AroundInvoke;
import jakarta.interceptor.InvocationContext;

/**
 * @author Stuart Douglas
 */
public class TopSecretInterceptor {

    public static boolean called = false;
    public static boolean postConstructCalled = false;

    // as this is a method level interceptor this should not be called
    // see the interceptors spec
    @PostConstruct
    public void postConstruct(final InvocationContext invocationContext) throws Exception {
        postConstructCalled = true;
        invocationContext.proceed();
    }

    @AroundInvoke
    public Object aroundInvoke(final InvocationContext invocationContext) throws Exception {
        called = true;
        return invocationContext.proceed();
    }
}
